Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 46 variants Io(Error), InvalidFile(String), InvalidSignature { position: SignaturePosition, expected: [u8; 8], found: [u8; 8], }, CorruptedHeader(String), HeaderLogGuidMismatch { header1_log_guid: Guid, header2_log_guid: Guid, }, HeaderSequenceNumberInvalid { sequence_number_1: u64, sequence_number_2: u64, }, UnsupportedVersion { version: u16, }, UnsupportedLogVersion { version: u16, }, HeaderLogNotAligned { field: String, value: u64, }, InvalidChecksum { expected: u32, actual: u32, }, InvalidBlockState(u8), InvalidSectorBitmapState(u8), StateMismatch { state: u8, description: String, }, BatFileOffsetUnaligned { offset_mb: u64, block_size: u32, }, BatEntryCountInsufficient { actual: u64, expected: u64, }, BatFileOffsetDuplicate { offset_mb: u64, }, InvalidRegionTable(String), RegionRequiredUnknown { guid: Guid, }, RegionOptionalUnknown { guid: Guid, }, InvalidMetadata(String), MetadataGuidUnknown { guid: Guid, }, MetadataRequiredMissing { guid: Guid, }, MetadataRequiredUnknown { guid: Guid, }, MetadataOptionalUnknown { guid: Guid, }, MetadataReservedFlagsSet { flags: u32, }, MetadataEntryReservedNonzero { reserved: u32, }, FileParametersReservedFlags { flags: u32, }, InvalidParentLocator(String), MetadataNotFound { guid: Guid, }, LogReplayRequired, LogEntryCorrupted(String), LogSequenceGap { expected: u64, found: u64, }, LogSequenceGuidMismatch { entry_log_guid: Guid, header_log_guid: Guid, }, LogActiveSequenceEmpty, BatEntryNotFound { index: u64, }, BlockNotPresent { block_idx: u64, state: String, }, SectorOutOfBounds { sector: u64, max: u64, }, ParentNotFound, ParentResolverRequired, ParentSectorSizeMismatch { child: u32, parent: u32, }, ParentMismatch { expected: Guid, actual: Guid, }, ParentLocatorGuidMismatch { expected: Guid, actual: Guid, }, ParentLocatorMissingLinkage, ParentLocatorLinkage2Conflict, InvalidParameter(String), ReadOnly,
}
Error type for VHDX operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Io(Error)



InvalidFile(String)



InvalidSignature

Fields

expected: [u8; 8]
found: [u8; 8]


CorruptedHeader(String)



HeaderLogGuidMismatch

Fields

header1_log_guid: Guid
header2_log_guid: Guid


HeaderSequenceNumberInvalid

Fields

sequence_number_1: u64
sequence_number_2: u64


UnsupportedVersion

Fields

version: u16


UnsupportedLogVersion

Fields

version: u16


HeaderLogNotAligned

Header LogLength or LogOffset is not aligned to 1 MB.

Standard: MS-VHDX-校验扩展标准 4.1 — HEADER_LOG_LENGTH_NOT_ALIGNED / HEADER_LOG_OFFSET_NOT_ALIGNED

Fields

field: String

Which field is misaligned (“log_length” or “log_offset”).

value: u64

The value of the misaligned field.



InvalidChecksum

Fields

expected: u32
actual: u32


InvalidBlockState(u8)



InvalidSectorBitmapState(u8)



StateMismatch

BAT block state is valid but incompatible with the disk type (e.g. Unmapped on non-differencing disk, or sector bitmap Present on non-differencing).

Standard: MS-VHDX-校验扩展标准 4.3 — BAT_ENTRY_STATE_MISMATCH

Fields

state: u8

The raw 3-bit state value.

description: String

Human-readable description of the mismatch (e.g. “sector bitmap state not NotPresent on non-differencing disk”).



BatFileOffsetUnaligned

BAT entry file offset is not aligned to the block size boundary.

Standard: MS-VHDX-校验扩展标准 4.3 — BAT_ENTRY_FILE_OFFSET_UNALIGNED

Fields

offset_mb: u64

The file offset in MB from the BAT entry.

block_size: u32

The block size in bytes.



BatEntryCountInsufficient

Fields

actual: u64
expected: u64


BatFileOffsetDuplicate

Fields

offset_mb: u64


InvalidRegionTable(String)



RegionRequiredUnknown

Fields

guid: Guid


RegionOptionalUnknown

Fields

guid: Guid


InvalidMetadata(String)



MetadataGuidUnknown

Fields

guid: Guid


MetadataRequiredMissing

Fields

guid: Guid


MetadataRequiredUnknown

Fields

guid: Guid


MetadataOptionalUnknown

Fields

guid: Guid


MetadataReservedFlagsSet

Fields

flags: u32


MetadataEntryReservedNonzero

Metadata Table Entry Reserved field is not zero.

Standard: MS-VHDX-校验扩展标准 4.4 — METADATA_ENTRY_RESERVED_NONZERO

Fields

reserved: u32


FileParametersReservedFlags

FileParameters item reserved flags (bits 2-31) are set.

Standard: MS-VHDX-校验扩展标准 4.4 — METADATA_FILE_PARAMETERS_RESERVED_FLAGS

Fields

flags: u32


InvalidParentLocator(String)



MetadataNotFound

Fields

guid: Guid


LogReplayRequired



LogEntryCorrupted(String)



LogSequenceGap

Fields

expected: u64
found: u64


LogSequenceGuidMismatch

Fields

entry_log_guid: Guid
header_log_guid: Guid


LogActiveSequenceEmpty



BatEntryNotFound

Fields

index: u64


BlockNotPresent

Fields

block_idx: u64
state: String


SectorOutOfBounds

Fields

sector: u64
max: u64


ParentNotFound



ParentResolverRequired



ParentSectorSizeMismatch

Fields

child: u32
parent: u32


ParentMismatch

Fields

expected: Guid
actual: Guid


ParentLocatorGuidMismatch

Fields

expected: Guid
actual: Guid


ParentLocatorMissingLinkage



ParentLocatorLinkage2Conflict



InvalidParameter(String)



ReadOnly