parse_active_header

Function parse_active_header 

pub fn parse_active_header(data: &[u8]) -> Result<VhdxHeader>
Select the active header from a raw byte slice covering both header copies. Returns the header with the highest sequence number whose CRC32C is valid.