pub struct LogEntryHeader<'a> { /* private fields */ }Expand description
Log entry header (64 bytes).
Layout (MS-VHDX 2.3.1.1):
[0..4] Signature ("loge")
[4..8] Checksum (CRC-32C)
[8..12] EntryLength
[12..16] Tail
[16..24] SequenceNumber
[24..28] DescriptorCount
[28..32] Reserved
[32..48] LogGuid
[48..56] FlushedFileOffset
[56..64] LastFileOffsetImplementations
Sourceimpl<'a> LogEntryHeader<'a>
impl<'a> LogEntryHeader<'a>
Sourcepub fn signature(&self) -> &'a [u8; 4]
pub fn signature(&self) -> &'a [u8; 4]
Entry signature. MUST be "loge" (0x65676F6C).
Panics
Panics if the header slice is shorter than 4 bytes.
Sourcepub fn checksum(&self) -> Crc32c
pub fn checksum(&self) -> Crc32c
CRC-32C checksum computed over the entire entry (checksum field zeroed).
Sourcepub fn entry_length(&self) -> u32
pub fn entry_length(&self) -> u32
Total length of the entry in bytes. MUST be a multiple of 4KB.
Sourcepub fn tail(&self) -> u32
pub fn tail(&self) -> u32
Offset from log start to the first entry of the active sequence. MUST be a multiple of 4KB.
Sourcepub fn sequence_number(&self) -> u64
pub fn sequence_number(&self) -> u64
Monotonically increasing sequence number. MUST be > 0.
Sourcepub fn descriptor_count(&self) -> u32
pub fn descriptor_count(&self) -> u32
Number of descriptors in this entry.
Sourcepub fn log_guid(&self) -> Guid
pub fn log_guid(&self) -> Guid
LogGuid that was present in the file header when this entry was written.
Sourcepub fn flushed_file_offset(&self) -> u64
pub fn flushed_file_offset(&self) -> u64
VHDX file size guaranteed to be stable on disk.
Sourcepub fn last_file_offset(&self) -> u64
pub fn last_file_offset(&self) -> u64
File size that all allocated structures fit into.