pub struct Vhdx { /* private fields */ }Expand description
A VHDX file with all metadata loaded in-memory.
Implementations
Sourceimpl Vhdx
impl Vhdx
Sourcepub fn load(path: impl AsRef<Path>) -> Vhdx
pub fn load(path: impl AsRef<Path>) -> Vhdx
Load a VHDX file from the filesystem.
Through opening the file, if there is a log to be replayed it will be applied during this function.
Sourcepub fn reader(&mut self) -> Reader<'_> ⓘ
pub fn reader(&mut self) -> Reader<'_> ⓘ
Use the disk as a Reader that implements std::io::Read and std::io::Seek.