Structs
- Vhdx
Header - Parsed VHDX header (the active copy with highest valid sequence number).
Constants
- HEADE
R1_ OFFSET - Offsets per MS-VHDX spec 2.1 — each block occupies a 64 KB slot within the first 1 MB of the file (the “header section”).
- HEADE
R2_ OFFSET - HEADER_
SIGNATURE - HEADER_
SIZE - REGION_
TABL E1_ OFFSET - REGION_
TABL E2_ OFFSET
Functions
- crc32c
- parse_
active_ header - Select the active header from a raw byte slice covering both header copies. Returns the header with the highest sequence number whose CRC32C is valid.